---
title: Observe
description: Represents a command for an agent to observe a cell in the world.
---

## Signature

```py
Observe(location: Location)
```

## Description

Represents a command for an agent to observe a specific cell at the given location in the world.  
When executed, the agent receives detailed information about the cell, including all layers present
and relevant cell attributes.

## Example

```py
loc = Location(6, 5)
agent.send(Observe(loc))
```
